==> cms-db_v0.7.9.tar.gz: admin/newuser.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('edituser');

$message = '';
if (isset($_POST['button'])) {
	if ($_POST['pass'] == $_POST['repeat']) {
		$vorhanden = false;
		if ($handle = opendir('../data/users')) {
			while (false !== ($file = readdir($handle))) {
				if($file != '.' && $file != '..') {
					include('../data/users/'.$file);
					if ($user == $_POST['user"']) {
						$vorhanden = true;
					}
				}
			}
			closedir($handle);
		}
		if (!$vorhanden) {
			$time = time();
			$pass = sha1($time.'.php'.$_POST['pass']);
			$writethis = '<?php
			$user = "'.$_POST['user'].'";
			$pass = "'.$pass.'";
			$user_pages = "'.$_POST['pages'].'";
			$user_files = "'.$_POST['files'].'";
			$user_includes = "'.$_POST['includes'].'";
			$user_template = "'.$_POST['template'].'";
			$user_gbook = "'.$_POST['gbook'].'";
			$user_blog = "'.$_POST['blog'].'";
			$user_stats = "'.$_POST['stats'].'";
			?>';
			$datei = fopen('../data/users/'.$time.'.php','w+');
			fwrite($datei,$writethis);
			fclose($datei);
			header('Location: users.php?saved='.$_POST['user'].'&'.SID);
		} else {
			$message = '<p class="error">'.locale('desc_error-username',true).'</p>';
		}
	} else {
		$message = '<p class="error">'.locale('desc_error-invalid-data',true).'</p>';
	}
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title_newuser') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php echo $message ?>

		<h2><?php locale('title_newuser') ?></h2>
		<p>
			<form action="newuser.php?<?php echo SID ?>" method="POST">
				<?php locale('label_username') ?>: <input type="text" name="user" value="<?php echo $user ?>" /><br />
				<?php locale('label_password') ?>: <input type="password" name="pass" value="" /><br />
				<?php locale('desc_repeat') ?> <input type="password" name="repeat" value="" /><br />
				<input type="checkbox" name="pages" id="pages" <?php if ($user_pages == 'on') { echo 'checked="checked"'; }?> />
				<label for="pages"><?php locale('label_user-pages') ?></label><br />
				<input type="checkbox" name="files" id="files" <?php if ($user_files == 'on') { echo 'checked="checked"'; }?> />
				<label for="files"><?php locale('label_user-files') ?></label><br />
				<input type="checkbox" name="includes" id="includes" <?php if ($user_includes == 'on') { echo 'checked="checked"'; }?> />
				<label for="includes"><?php locale('label_user-includes') ?></label><br />
				<input type="checkbox" name="template" id="template" <?php if ($user_template == 'on') { echo 'checked="checked"'; }?> />
				<label for="template"><?php locale('label_user-template') ?></label><br />
				<input type="checkbox" name="gbook" id="gbook" <?php if ($user_gbook == 'on') { echo 'checked="checked"'; }?> />
				<label for="gbook"><?php locale('label_user-gbook') ?></label><br />
				<input type="checkbox" name="blog" id="blog" <?php if ($user_blog == 'on') { echo 'checked="checked"'; }?> />
				<label for="blog"><?php locale('label_user-blog') ?></label><br />
				<input type="checkbox" name="stats" id="stats" <?php if ($user_stats == 'on') { echo 'checked="checked"'; }?> />
				<label for="stats"><?php locale('label_user-stats') ?></label><br /><br />
				<i><?php locale('desc_users') ?></i><br /><br />
				<input type="submit" name="button" value="<?php locale('button_save') ?>">
				<a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('button_cancel') ?></a>
			</form>
		</p>

	</body>
</html>

==> cms-db_v0.7.11.tar.gz: admin/newuser.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('edituser');

$message = '';
include('escape.inc.php');
if (isset($_POST['button'])) {
	if ($_POST['pass'] == $_POST['repeat']) {
		$vorhanden = false;
		if ($handle = opendir('../data/users')) {
			while (false !== ($file = readdir($handle))) {
				if($file != '.' && $file != '..') {
					include('../data/users/'.$file);
					if ($user == $_POST['user"']) {
						$vorhanden = true;
					}
				}
			}
			closedir($handle);
		}
		if (!$vorhanden) {
			$time = time();
			$pass = sha1($time.'.php'.escapeSL($_POST['pass']));
			$writethis = '<?php
			$user = \''.escapeForm($_POST['user']).'\';
			$pass = \''.escapeSave($pass).'\';
			$user_pages = \''.escapeForm($_POST['pages']).'\';
			$user_files = \''.escapeForm($_POST['files']).'\';
			$user_includes = \''.escapeForm($_POST['includes']).'\';
			$user_template = \''.escapeForm($_POST['template']).'\';
			$user_gbook = \''.escapeForm($_POST['gbook']).'\';
			$user_blog = \''.escapeForm($_POST['blog']).'\';
			$user_stats = \''.escapeForm($_POST['stats']).'\';
			?>';
			file_put_contents('../data/users/'.$time.'.php', $writethis);
			header('Location: users.php?saved='.urlencode($_POST['user']).'&'.SID);
		} else {
			$message = '<p class="error">'.locale('desc_error-username',true).'</p>';
		}
	} else {
		$message = '<p class="error">'.locale('desc_error-invalid-data',true).'</p>';
	}
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title_newuser') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="ftpsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_ftpsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php echo $message ?>

		<h2><?php locale('title_newuser') ?></h2>
		<p>
			<form action="newuser.php?<?php echo SID ?>" method="POST">
				<?php locale('label_username') ?>: <input type="text" name="user" value="" /><br />
				<?php locale('label_password') ?>: <input type="password" name="pass" value="" /><br />
				<?php locale('desc_repeat') ?> <input type="password" name="repeat" value="" /><br />
				<input type="checkbox" name="pages" id="pages" <?php if ($user_pages == 'on') { echo 'checked="checked"'; }?> />
				<label for="pages"><?php locale('label_user-pages') ?></label><br />
				<input type="checkbox" name="files" id="files" <?php if ($user_files == 'on') { echo 'checked="checked"'; }?> />
				<label for="files"><?php locale('label_user-files') ?></label><br />
				<input type="checkbox" name="includes" id="includes" <?php if ($user_includes == 'on') { echo 'checked="checked"'; }?> />
				<label for="includes"><?php locale('label_user-includes') ?></label><br />
				<input type="checkbox" name="template" id="template" <?php if ($user_template == 'on') { echo 'checked="checked"'; }?> />
				<label for="template"><?php locale('label_user-template') ?></label><br />
				<input type="checkbox" name="gbook" id="gbook" <?php if ($user_gbook == 'on') { echo 'checked="checked"'; }?> />
				<label for="gbook"><?php locale('label_user-gbook') ?></label><br />
				<input type="checkbox" name="blog" id="blog" <?php if ($user_blog == 'on') { echo 'checked="checked"'; }?> />
				<label for="blog"><?php locale('label_user-blog') ?></label><br />
				<input type="checkbox" name="stats" id="stats" <?php if ($user_stats == 'on') { echo 'checked="checked"'; }?> />
				<label for="stats"><?php locale('label_user-stats') ?></label><br /><br />
				<i><?php locale('desc_users') ?></i><br /><br />
				<input type="submit" name="button" value="<?php locale('button_save') ?>">
				<a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('button_cancel') ?></a>
			</form>
		</p>

	</body>
</html>
